//--------------------------------------------------------------------
//                                                                    
//  Module:       SalesChart                                       
//  Description:  SalesChart
//                                                                    
//--------------------------------------------------------------------

import java.awt.*;
import java.awt.event.*;
import java.applet.*;
import java.util.*;
import java.io.*;
import java.net.*;


public class SalesChart extends JDPClassLayout  {

	JDPUser user;
	JDPJagg jaggSQL;
	JDPPopupMessage popuppanel;
	JDPMaskEdit JDPMaskEditMain;
	String moduleParameter;
	//
	//  Declare screen components
	//
	Panel Main;
	JDPChart ChartLayout1;
	JDPSearchResults ResultList1;

	public void InitClass(JDPUser user, Panel targetPanel, String moduleParameter) {

		this.user = user;
		this.moduleParameter = moduleParameter;
		//
		//  Set JAGG settings for this class
		//
		jaggSQL = new JDPJagg(user.jaggPath);

		setLayout(new BorderLayout());
		popuppanel = new JDPPopupMessage(user,this);
		add(popuppanel);
		JDPMaskEditMain = new JDPMaskEdit();

		Main = new Panel();
		ChartLayout1Main();
		ResultList1Main();

		Main.setLayout(new BorderLayout());
		add("Center", Main);
		Main.add("Center", ChartLayout1);
		Main.add("West", ResultList1);



		//
		//  Initialise Components
		//
		InitComponents();
		//
		//  Add the handle to this panel to the global vector so other panels can
		//  access this one
		//
		user.gParm.addElement(this);
	}

	//
	//  Handle screen events
	//
	public boolean handleEvent(Event e) {

		switch (e.id) {
		case Event.ACTION_EVENT:
			if (e.target.equals(ResultList1)) {
				ChartLayout1LoadData(ResultList1.getSelectedKey());
				return true;
			}
			return false;

		case Event.MOUSE_MOVE:
		case Event.MOUSE_ENTER:
		case Event.MOUSE_EXIT:
			popuppanel.postEvent(e);
			return false;

		default:
			return false;

		}
	}


	//
	//  Initialise other components by calling their methods
	//
	public void InitComponents() {

		

	}
	//
	//  Main initialization method
	//
	public void ChartLayout1Main() {

		ChartLayout1SetChartParms();
		ChartLayout1LoadData(null);

	}


	//
	//  Load the parameters for the selected chart
	//
	public void ChartLayout1SetChartParms() {

		JDPChartParms p;
		if (ChartLayout1 == null) {
			p = new JDPChartParms();
			ChartLayout1 = new JDPChart(user, p);
		} else {
			p = ChartLayout1.p;
		}

		p.chartType = 5;
		p.autoscale = true;
		p.autozoom = true;

		p.chartTitle = "Sales by Store";
		p.chartTitleFont = user.boldFont.getName();
		p.chartTitleColor = user.u._cvtcolor("Black");

		p.xaxisTitle = "";
		p.xaxisTitleFont = user.boldFont.getName();
		p.xaxisTitleColor = user.u._cvtcolor("Black");

		p.yaxisLabel = new String[10];

		p.elementLegendFont = user.boldFont.getName();

		p.xaxisLabelColor = user.u._cvtcolor("Black");
		p.yaxisLabelColor = user.u._cvtcolor("Black");
		p.chartFrameColor = user.u._cvtcolor("Black");

		p.elementLegend = new String[1];
		p.elementColor = new Color[1];
		p.elementBorderColor = new Color[1];
		p.elementLegend[0] = "Qty";
		p.elementColor[0] = user.u._cvtcolor("Magenta");
		p.elementBorderColor[0] = user.u._cvtcolor("Black");

		p.gridLineSetting = JDPChart.HORIZONTAL + JDPChart.VERTICAL + JDPChart.FOREGROUND + JDPChart.BACKGROUND;
		p.gridColor = user.u._cvtcolor("Gray");

		p.maxPlotValue = 100;
		p.minPlotValue = 0;

		if ((p.chartType == JDPChart.COLUMN) || (p.chartType == JDPChart.BAR) ||
			(p.chartType == JDPChart.AREA)) {
			p.autozoom = false;
		}

		p.pieLabel = p.elementLegend;
		p.pieLabelColor = p.xaxisTitleColor;

	}


	//
	//  Load the chart with the specified parameters and selected data
	//
	public void ChartLayout1LoadData(String[] keys) {

		ChartLayout1LoadDataMain(keys, null);
	}


	//
	//  Load the chart with the specified parameters and selected data
	//
	public void ChartLayout1LoadDataFromWhereClause(String whereClause) {

		int fPos = whereClause.indexOf("WHERE ");
		whereClause = " AND" + whereClause.substring(fPos+5);
		String[] keys = new String[0];

		ChartLayout1LoadDataMain(keys, whereClause);
	}


	//
	//  Load the chart with the specified parameters and selected data
	//
	void ChartLayout1LoadDataMain(String[] keys, String whereClauseParm) {

		JDPChartParms p = ChartLayout1.p;

		StringTokenizer stok;
		int recCount = 0;
		Vector results = new Vector();
		String sep = jaggSQL.getSEP();
		int actualRows = 0;
		String row;
		String whereClause = "(1=1)";

		int groupCount = 1;
		int seriesCount = 0;

		if (keys != null && keys.length > 0 && keys[0] != null) whereClause += " AND stor_id='" + keys[0]+ "'" ;
		if (whereClauseParm != null) {
			whereClause += whereClause;
		}
		String SQL = "SELECT LEFT(format(ord_date, 'yy/mm/dd'),5),SUM(qty) FROM dbo_sales  WHERE " + whereClause + " GROUP BY LEFT(format(ord_date, 'yy/mm/dd'),5) ORDER BY SUM(qty) DESC";


		user.mainmsg.setStatusMsg(JDPLang.get("Message0"), 0);

		jaggSQL.setDSN("JDP Tutorial");
		jaggSQL.setUID("");
		jaggSQL.setPWD("");
		jaggSQL.setMRW("1000");
		jaggSQL.setTOUT("60");

		recCount = jaggSQL.execSQL(SQL, results);

		if(recCount == -1) {
			user.u.setSqlMessage(jaggSQL,SQL);
			return;
		}
		if(recCount == 0) {
			user.mainmsg.setStatusMsg(JDPLang.get("Message10"),10);
			ChartLayout1.hide();
			return;
		}
		ChartLayout1.show();

		//
		//  Initialise result arrays
		//
		int columnCount = jaggSQL.getColumnCount();
		actualRows = jaggSQL.getRowCount();

		if (seriesCount <= 0) {
			p.chartData = new float[columnCount-groupCount][actualRows];
			p.xaxisLabel = new String[actualRows];
			p.piechartData = new float[actualRows];
			p.pieSplitSegment = new boolean[actualRows];
			p.pieLabel = new String[actualRows];
			if (p.chartType == JDPChart.PIE ||
				p.chartType == JDPChart.GANTT) {
				p.elementColor = new Color[actualRows];
				p.elementBorderColor = new Color[actualRows];
 				p.elementLegend = new String[actualRows];
			}
			for (int ix=0; ix<actualRows; ix++) {
				row = (String)results.elementAt(ix);
				stok = new StringTokenizer(row,sep);
				p.xaxisLabel[ix] = "";
				if (groupCount > 0) p.xaxisLabel[ix] = stok.nextToken().trim();
				for (int iz=0; iz<columnCount-groupCount; iz++) {
					if (p.chartType == JDPChart.GANTT) {
						String date = stok.nextToken();
						Date thisDate = new Date(Integer.parseInt(date.substring(2,4)),Integer.parseInt(date.substring(5,7))-1,Integer.parseInt(date.substring(8,10)));
						long val = thisDate.getTime()/(86400000);
						p.chartData[iz][ix] = (float)val;
					} else {
						p.chartData[iz][ix] = Float.valueOf(stok.nextToken().trim()).floatValue();
					}
				}
				p.pieLabel[ix] = p.xaxisLabel[ix];
				p.piechartData[ix] = p.chartData[0][ix];
				if (p.chartType == JDPChart.PIE ||
					p.chartType == JDPChart.GANTT) {
					p.elementColor[ix] = JDPUtils.colorList[ix%12];
					p.elementBorderColor[ix] = Color.black;
 					p.elementLegend[ix] = p.pieLabel[ix];
				}
			}
		} else {
			float[][] tempchartData = new float[1000][actualRows];
			p.xaxisLabel = new String[actualRows];
			Vector group = new Vector();
			if (groupCount == 0) group.addElement("");
			Vector series = new Vector();
			for (int ix=0; ix<actualRows; ix++) {
				row = (String)results.elementAt(ix);
				stok = new StringTokenizer(row,sep);
				p.xaxisLabel[ix] = "";
				int groupIndex = 0;
				if (groupCount > 0) {
					String groupValue = stok.nextToken().trim();
					groupIndex = group.indexOf(groupValue);
					if (groupIndex < 0) {
						group.addElement(groupValue);
						groupIndex = group.indexOf(groupValue);
						p.xaxisLabel[groupIndex] = groupValue;
					}
				}
				String seriesValue = stok.nextToken().trim();
				int seriesIndex = series.indexOf(seriesValue);
				if (seriesIndex < 0) {
					series.addElement(seriesValue);
					seriesIndex = series.indexOf(seriesValue);
				}
				tempchartData[seriesIndex][groupIndex] = Float.valueOf(stok.nextToken().trim()).floatValue();
			}

			int numbars = series.size();
			p.chartData = new float[numbars][group.size()];
			for (int ix=0; ix<numbars; ix++) {
				for (int iy=0; iy<group.size(); iy++) {
					p.chartData[ix][iy] = tempchartData[ix][iy];
				}
			}
			p.elementColor = new Color[numbars];
			p.elementBorderColor = new Color[numbars];
 			p.elementLegend = new String[numbars];
			for (int ix=0; ix<numbars; ix++) {
				p.elementColor[ix] = JDPUtils.colorList[ix%12];
				p.elementBorderColor[ix] = Color.black;
 				p.elementLegend[ix] = (String)series.elementAt(ix);
			}
		}
		ChartLayout1.calculateScaling();
		ChartLayout1.repaint();

		user.mainmsg.clearStatusMsg();
	}


	//
	//  Create and load the Result List Panel
	//
	public void ResultList1Main() {

		String ResultList1sf = "stor_id";
		String[] ResultList1df = {};
		String ResultList1wc = "(1=1)";
		String[] ResultList1sct = {"Stor name"};
		String[] ResultList1sc = {"stor_name"};
		jaggSQL.setDSN("JDP Tutorial");
		jaggSQL.setJdbcDriver("sun.jdbc.odbc.JdbcOdbcDriver");
		jaggSQL.setJdbcPrefix("jdbc:odbc:");
		jaggSQL.setJdbcSuffix("JDP Tutorial");
		jaggSQL.setUID("");
		jaggSQL.setPWD("");
		jaggSQL.setCSTR(" ");
		jaggSQL.setMRW("1000");
		jaggSQL.setTOUT("60");
		ResultList1 = new JDPSearchResults(user, targetPanel, true, jaggSQL, false, ResultList1sf, ResultList1df, ResultList1wc, ResultList1sct, ResultList1sc, ResultList1sc, "", true, "Total Entries:");
		int[] ResultList1icons = new int[8];
		ResultList1icons[0] = 3;
		ResultList1icons[1] = 5;
		ResultList1.setMinWidth(130);
		ResultList1.setIcons(ResultList1icons);
		ResultList1.setFromWhereClause(" FROM dbo_stores WHERE (1=1)");
		ResultList1.clearList("");
		ResultList1.loadList();
	}


}

